@@ -1,8 +1,7 @@
 // Predefined symbols and macros -*- C++ -*-
 
 // Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-// 2006, 2007
-// Free Software Foundation, Inc.
+// 2006, 2007 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -34,8 +33,8 @@
  *  You should not attempt to use it directly.
  */
 
-#ifndef _CXXCONFIG
-#define _CXXCONFIG 1
+#ifndef _GLIBCXX_CXX_CONFIG_H
+#define _GLIBCXX_CXX_CONFIG_H 1
 
 // Pick up any OS-specific definitions.
 #include <bits/os_defines.h>
@@ -44,44 +43,162 @@
 #include <bits/cpu_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20080519 
+#define __GLIBCXX__ 20080606 
 
 // Macros for visibility.
+// _GLIBCXX_HAVE_ATTRIBUTE_VISIBILITY
+// _GLIBCXX_VISIBILITY_ATTR
 # define _GLIBCXX_HAVE_ATTRIBUTE_VISIBILITY 1
 
 #if _GLIBCXX_HAVE_ATTRIBUTE_VISIBILITY
-#define _GLIBCXX_VISIBILITY(V) __attribute__ ((__visibility__ (#V)))
+# define _GLIBCXX_VISIBILITY_ATTR(V) __attribute__ ((__visibility__ (#V)))
 #else
-#define _GLIBCXX_VISIBILITY(V) 
+# define _GLIBCXX_VISIBILITY_ATTR(V) 
 #endif
 
-// Macros for controlling various namespace association schemes and modes.
+// Macros for deprecated.
+// _GLIBCXX_DEPRECATED
+// _GLIBCXX_DEPRECATED_ATTR
+#ifndef _GLIBCXX_DEPRECATED
+# define _GLIBCXX_DEPRECATED 1
+#endif
+
+#if defined(__DEPRECATED) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+# define _GLIBCXX_DEPRECATED_ATTR __attribute__ ((__deprecated__))
+#else
+# define _GLIBCXX_DEPRECATED_ATTR
+#endif
+
+// Macros for activating various namespace association modes.
+// _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG
+// _GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL
+// _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION
+
+// Guide to libstdc++ namespaces.
+/*
+  namespace std
+  {
+    namespace __debug { }
+    namespace __parallel { }
+    namespace __norm { } // __normative, __shadow, __replaced
+    namespace __cxx1998 { }
+
+    namespace tr1 { }
+  }
+*/
+
 #ifdef _GLIBCXX_DEBUG
 # define _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG 1
 #endif
 
+#ifdef _GLIBCXX_PARALLEL
+# define _GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL 1
+#endif
+
 # define _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION 0 
 
-// Macros for namespace scope.
+// Defined if any namespace association modes are active.
+#if _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG \
+  || _GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL \
+  || _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION
+# define _GLIBCXX_USE_NAMESPACE_ASSOCIATION 1
+#endif
+
+// Macros for namespace scope. Either namespace std:: or the name
+// of some nested namespace within it.
+// _GLIBCXX_STD
+// _GLIBCXX_STD_D
+// _GLIBCXX_STD_P
+
+//
+// Macros for enclosing namespaces and possibly nested namespaces.
 // _GLIBCXX_BEGIN_NAMESPACE
 // _GLIBCXX_END_NAMESPACE
 // _GLIBCXX_BEGIN_NESTED_NAMESPACE
 // _GLIBCXX_END_NESTED_NAMESPACE
-#if _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION
-# define _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, Y)  namespace X { namespace Y _GLIBCXX_VISIBILITY(default) {
-# define _GLIBCXX_END_NESTED_NAMESPACE } }
-# define _GLIBCXX_BEGIN_NAMESPACE(X) _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, _6)
-# define _GLIBCXX_END_NAMESPACE _GLIBCXX_END_NESTED_NAMESPACE
+// _GLIBCXX_BEGIN_POTENTIAL_NESTED_NAMESPACE
+// _GLIBCXX_END_POTENTIAL_NESTED_NAMESPACE
+#ifndef _GLIBCXX_USE_NAMESPACE_ASSOCIATION
+# define _GLIBCXX_STD_D _GLIBCXX_STD
+# define _GLIBCXX_STD_P _GLIBCXX_STD
+# define _GLIBCXX_STD std
+# define _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, Y) _GLIBCXX_BEGIN_NAMESPACE(X)
+# define _GLIBCXX_END_NESTED_NAMESPACE _GLIBCXX_END_NAMESPACE
+# define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) {
+# define _GLIBCXX_END_NAMESPACE }
 #else
-# define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY(default) { 
-# define _GLIBCXX_END_NAMESPACE } 
-# if _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG
-#  define _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, Y) namespace X { namespace Y _GLIBCXX_VISIBILITY(default) {
-#  define _GLIBCXX_END_NESTED_NAMESPACE  } }
-# else
-#  define _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, Y) _GLIBCXX_BEGIN_NAMESPACE(X)
-#  define _GLIBCXX_END_NESTED_NAMESPACE _GLIBCXX_END_NAMESPACE
+
+# if _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION // && not anything else
+#  define _GLIBCXX_STD_D _GLIBCXX_STD
+#  define _GLIBCXX_STD_P _GLIBCXX_STD
+#  define _GLIBCXX_STD _6
+#  define _GLIBCXX_BEGIN_NAMESPACE(X) _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, _6)
+#  define _GLIBCXX_END_NAMESPACE _GLIBCXX_END_NESTED_NAMESPACE
 # endif
+
+//  debug
+# if _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG && !_GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL
+#  define _GLIBCXX_STD_D __norm
+#  define _GLIBCXX_STD_P _GLIBCXX_STD
+#  define _GLIBCXX_STD __cxx1998
+#  define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) { 
+#  define _GLIBCXX_END_NAMESPACE }
+#  define _GLIBCXX_EXTERN_TEMPLATE 0
+# endif
+
+// parallel
+# if _GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL && !_GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG 
+#  define _GLIBCXX_STD_D _GLIBCXX_STD
+#  define _GLIBCXX_STD_P __norm
+#  define _GLIBCXX_STD __cxx1998
+#  define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) { 
+#  define _GLIBCXX_END_NAMESPACE }
+#  define _GLIBCXX_EXTERN_TEMPLATE 0
+# endif
+
+// debug + parallel
+# if _GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL && _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG 
+#  define _GLIBCXX_STD_D __norm
+#  define _GLIBCXX_STD_P __norm
+#  define _GLIBCXX_STD __cxx1998
+#  define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) { 
+#  define _GLIBCXX_END_NAMESPACE }
+#  define _GLIBCXX_EXTERN_TEMPLATE 0
+# endif
+
+# if __NO_INLINE__ && !__GXX_WEAK__
+#  warning currently using namespace associated mode which may fail \
+   without inlining due to lack of weak symbols
+# endif
+
+# define _GLIBCXX_BEGIN_NESTED_NAMESPACE(X, Y)  namespace X { namespace Y _GLIBCXX_VISIBILITY_ATTR(default) {
+# define _GLIBCXX_END_NESTED_NAMESPACE } }
+#endif
+
+// Namespace associations for debug mode.
+#if _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG
+namespace std
+{ 
+  namespace __norm { } 
+  namespace __debug { }
+  namespace __cxx1998 { }
+
+  using namespace __debug __attribute__ ((strong)); 
+  using namespace __cxx1998 __attribute__ ((strong)); 
+}
+#endif
+
+// Namespace associations for parallel mode.
+#if _GLIBCXX_NAMESPACE_ASSOCIATION_PARALLEL
+namespace std
+{ 
+  namespace __norm { } 
+  namespace __parallel { }
+  namespace __cxx1998 { }
+
+  using namespace __parallel __attribute__ ((strong));
+  using namespace __cxx1998 __attribute__ ((strong)); 
+}
 #endif
 
 // Namespace associations for versioning mode.
@@ -92,7 +209,6 @@ namespace std
   using namespace _6 __attribute__ ((strong));
 }
 
-// In addition, other supported namespace configurations.
 namespace __gnu_cxx 
 { 
   namespace _6 { }
@@ -109,39 +225,7 @@ namespace std
 }
 #endif
 
-// Namespace associations for debug mode.
-#if _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG
-namespace std
-{ 
-  namespace __norm { }
-  namespace __debug { }
-  using namespace __debug __attribute__ ((strong)); 
-}
-
-namespace __gnu_cxx
-{
-  namespace __norm { }
-  namespace __debug { }
-  using namespace __debug __attribute__ ((strong)); 
-}
-
-# define _GLIBCXX_STD __norm
-# define _GLIBCXX_EXT __norm
-# define _GLIBCXX_EXTERN_TEMPLATE 0
-# if __NO_INLINE__ && !__GXX_WEAK__
-#  warning debug mode without inlining may fail due to lack of weak symbols
-# endif
-#else
-#if _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION
-# define _GLIBCXX_STD _6
-# define _GLIBCXX_EXT _6
-#else
-# define _GLIBCXX_STD std
-# define _GLIBCXX_EXT __gnu_cxx
-#endif
-#endif
-
-/* Define if compatibility should be provided for -mlong-double-64. */
+// Define if compatibility should be provided for -mlong-double-64.
 #undef _GLIBCXX_LONG_DOUBLE_COMPAT
 
 // XXX GLIBCXX_ABI Deprecated
@@ -183,6 +267,14 @@ _GLIBCXX_END_NAMESPACE
 # define _GLIBCXX_WEAK_DEFINITION
 #endif
 
+// Macro used to indicate that the native "C" includes, when compiled
+// as "C++", have declarations in namespace std and not the global
+// namespace. Note, this is unrelated to possible "C" compatibility
+// includes that inject C90/C99 names into the global namespace.
+#if __cplusplus == 199711L
+# define _GLIBCXX_NAMESPACE_GLOBAL_INJECTION 1
+#endif
+
 // The remainder of the prewritten config is automatic; all the
 // user hooks are listed above.
 
@@ -231,6 +323,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `atanl' function. */
 #define _GLIBCXX_HAVE_ATANL 1
 
+/* Define to 1 if the target assembler supports thread-local storage. */
+/* #undef _GLIBCXX_HAVE_CC_TLS */
+
 /* Define to 1 if you have the `ceilf' function. */
 #define _GLIBCXX_HAVE_CEILF 1
 
@@ -261,6 +356,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `cosl' function. */
 #define _GLIBCXX_HAVE_COSL 1
 
+/* Define to 1 if you have the <dlfcn.h> header file. */
+#define _GLIBCXX_HAVE_DLFCN_H 1
+
 /* Define to 1 if you have the <endian.h> header file. */
 #define _GLIBCXX_HAVE_ENDIAN_H 1
 
@@ -315,6 +413,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `frexpl' function. */
 #define _GLIBCXX_HAVE_FREXPL 1
 
+/* Define to 1 if you have the <gconf.h> header file. */
+/* #undef _GLIBCXX_HAVE_GCONF_H */
+
 /* Define to 1 if you have the <gconv.h> header file. */
 #define _GLIBCXX_HAVE_GCONV_H 1
 
@@ -337,15 +438,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `hypotl' function. */
 #define _GLIBCXX_HAVE_HYPOTL 1
 
-/* Define to 1 if you have the `iconv' function. */
+/* Define if you have the iconv() function. */
 #define _GLIBCXX_HAVE_ICONV 1
 
-/* Define to 1 if you have the `iconv_close' function. */
-#define _GLIBCXX_HAVE_ICONV_CLOSE 1
-
-/* Define to 1 if you have the `iconv_open' function. */
-#define _GLIBCXX_HAVE_ICONV_OPEN 1
-
 /* Define to 1 if you have the <ieeefp.h> header file. */
 /* #undef _GLIBCXX_HAVE_IEEEFP_H */
 
@@ -406,6 +501,9 @@ _GLIBCXX_END_NAMESPACE
 /* Only used in build directory testsuite_hooks.h. */
 #define _GLIBCXX_HAVE_LIMIT_VMEM 0
 
+/* Define if futex syscall is available. */
+#define _GLIBCXX_HAVE_LINUX_FUTEX 1
+
 /* Define to 1 if you have the <locale.h> header file. */
 #define _GLIBCXX_HAVE_LOCALE_H 1
 
@@ -448,9 +546,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the <nan.h> header file. */
 /* #undef _GLIBCXX_HAVE_NAN_H */
 
-/* Define to 1 if you have the `nl_langinfo' function. */
-#define _GLIBCXX_HAVE_NL_LANGINFO 1
-
 /* Define if poll is available in <poll.h>. */
 #define _GLIBCXX_HAVE_POLL 1
 
@@ -580,6 +675,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `tanl' function. */
 #define _GLIBCXX_HAVE_TANL 1
 
+/* Define to 1 if you have the <tgmath.h> header file. */
+#define _GLIBCXX_HAVE_TGMATH_H 1
+
 /* Define to 1 if the target supports thread-local storage. */
 #define _GLIBCXX_HAVE_TLS 1
 
@@ -850,6 +948,13 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `__signbitl' function. */
 #define _GLIBCXX_HAVE___SIGNBITL 1
 
+/* Define as const if the declaration of iconv() needs const. */
+#define _GLIBCXX_ICONV_CONST 
+
+/* Define to the sub-directory in which libtool stores uninstalled libraries.
+   */
+#define LT_OBJDIR ".libs/"
+
 /* Name of package */
 /* #undef _GLIBCXX_PACKAGE */
 
@@ -950,9 +1055,6 @@ _GLIBCXX_END_NAMESPACE
    namespace std::tr1. */
 #define _GLIBCXX_USE_C99_STDINT_TR1 1
 
-/* Define if iconv and related functions exist and are usable. */
-#define _GLIBCXX_USE_ICONV 1
-
 /* Define if LFS support is available. */
 #define _GLIBCXX_USE_LFS 1
 
@@ -1299,4 +1401,4 @@ _GLIBCXX_END_NAMESPACE
 # define tanl _tanl
 #endif
 
-#endif // _CXXCONFIG_
+#endif // _GLIBCXX_CXX_CONFIG_H
